@@ -54,7 +54,10 @@
 #' @param loadingSpin a boolean value indicating if loading spinner should be enabled. By default it is set to false.
 #' @param style a named list to specify style for each cell. The name should be the cell address and the value should be
 #' a valid 'css' string with styles.  For example, to style cell 'A1', the list should look like
+#' 'type' is not specified in 'columns' attribute
 #' \code{style = list("A1" = "background-color: gray;")}.
+#' @param autoColTypes a boolean value indicating if column type should be automatically detected if
+#' @param showToolbar a boolean value indicating if toolbar should be shown. By default it is set to false.
 #' @import jsonlite
 #' @import htmlwidgets
 #' @example inst/examples/examples_widget.R
@@ -86,7 +89,9 @@ excelTable <-
            fullscreen = FALSE,
            lazyLoading = FALSE,
            loadingSpin = FALSE,
-           style = NULL) {
+           style = NULL,
+           autoColTypes = TRUE,
+           showToolbar = FALSE) {
     # List of parameters to send to js
     paramList <- list()
 
@@ -137,8 +142,7 @@ excelTable <-
       paramList$colHeaders <- jsonlite::toJSON(colHeaders)
 
 
-    } else if (!is.null(columns))
-    {
+    } else if (!is.null(columns)) {
       #Check if 'columns' is a dataframe
       if (!is.data.frame(columns)) {
         stop("'columns' must be a dataframe, cannot be ", class(columns))
@@ -189,6 +193,29 @@ excelTable <-
 
     }
 
+    #Check autoColTypes
+    #If 'type' attribute is not specified in column and autoColTypes is true, then we map this and add it
+    #column attributes
+    if(autoColTypes && !is.null(data)){
+      if(is.null(columns)){
+        message("Since 'type' attribute is not specified and autoColTypes is true, detecting type from 'data'")
+
+        colTypes <- get_col_types(data)
+        columns <- data.frame(type=colTypes)
+        paramList$columns <- jsonlite::toJSON(columns)
+      }else{
+        if(!"type" %in% colnames(columns) && autoColTypes){
+          message("Since 'type' attribute is not specified and autoColTypes is true, detecting type from 'data'")
+
+          colTypes <- get_col_types(data)
+          columns$type <- colTypes
+          paramList$columns <-
+            jsonlite::toJSON(columns[colnames(columns) %in% colAttributes])
+        }
+      }
+    }
+
+
     #Check row height
     if (!is.null(rowHeight)) {
       if (!is.data.frame(rowHeight) && !is.matrix(rowHeight)) {
@@ -210,7 +237,7 @@ excelTable <-
     if (!is.null(nestedHeaders)) {
       # nestedHeaders should be list
       if (!is.list(nestedHeaders)) {
-        stop("'nestedHeaders' must be a list of dataframe(s), cannot be ", 
+        stop("'nestedHeaders' must be a list of dataframe(s), cannot be ",
         class(nestedHeaders))
       }
 
@@ -316,7 +343,8 @@ excelTable <-
       "search",
       "fullscreen",
       "lazyLoading",
-      "loadingSpin"
+      "loadingSpin",
+      "showToolbar"
     )) {
       argvalue <- get(arg)
       if(!is.null(argvalue)) {
